@@ -62,30 +62,34 @@ prob_template <- tibble::tibble(
 )
 
 
-predict_survival_na <- function(eval_time, interval = "none") {
-  ret <- tibble(.eval_time = eval_time, .pred_survival = NA_real_)
+predict_survival_na <- function(eval_time, interval = "none", penalty = NULL) {
+  if (!is.null(penalty)) {
+    n_penalty <- length(penalty)
+    n_eval_time <- length(eval_time)
+    ret <- tibble::new_tibble(
+      list(
+        penalty = rep(penalty, each = n_eval_time),
+        .eval_time = rep(eval_time, times = n_penalty),
+        .pred_survival = rep(NA_real_, n_penalty * n_eval_time)
+      )
+    )
+  } else {
+    ret <- tibble::new_tibble(
+      list(
+        .eval_time = eval_time,
+        .pred_survival = rep(NA_real_, length(eval_time))
+      )
+    )
+  }
+  
   if (interval == "confidence") {
     ret <- ret %>%
       dplyr::mutate(.pred_lower = NA_real_, .pred_upper = NA_real_)
   }
+
   ret
 }
 
-# -------------------------------------------------------------------------
-
-# This function takes a matrix and turns it into list of nested tibbles
-# suitable for predict_survival
-matrix_to_nested_tibbles_survival <- function(x, eval_time) {
-  res <- tibble(
-    .row = rep(seq_len(nrow(x)), each = ncol(x)),
-    .eval_time = rep(eval_time, nrow(x)),
-    .pred_survival = as.numeric(t(x))
-  )
-
-  dplyr::group_nest(res, .row, .key = ".pred")$.pred
-}
-
-
 # summary_survfit helpers -------------------------------------------------
 
 survfit_summary_typestable <- function(object) {
