@@ -1,5 +1,7 @@
 #' A wrapper for survival probabilities with partykit models
-#' @param object A model object from `partykit::ctree()` or `partykit::cforest()`.
+#' @param object A parsnip `model_fit` object resulting from 
+#' [decision_tree() with engine = "partykit"][parsnip::details_decision_tree_partykit] or 
+#' [rand_forest() with engine = "partykit"][parsnip::details_rand_forest_partykit].
 #' @param new_data A data frame to be predicted.
 #' @param eval_time A vector of times to predict the survival probability.
 #' @param time Deprecated in favor of `eval_time`. A vector of times to predict the survival probability.
@@ -7,17 +9,26 @@
 #' @return A tibble with a list column of nested tibbles.
 #' @export
 #' @keywords internal
-#' @examples
-#' library(partykit)
-#' c_tree <- ctree(Surv(time, status) ~ age + ph.ecog, data = lung)
-#' survival_prob_partykit(c_tree, lung[1:3, ], eval_time = 100)
-#' c_forest <- cforest(Surv(time, status) ~ age + ph.ecog, data = lung, ntree = 10)
-#' survival_prob_partykit(c_forest, lung[1:3, ], eval_time = 100)
+#' @examplesIf rlang::is_installed(c("partykit", "coin"))
+#' tree <- decision_tree() %>%
+#'   set_mode("censored regression") %>%
+#'   set_engine("partykit") %>%
+#'   fit(Surv(time, status) ~ age + ph.ecog, data = lung)
+#' survival_prob_partykit(tree, lung[1:3, ], eval_time = 100)
+#' forest <- rand_forest() %>%
+#'   set_mode("censored regression") %>%
+#'   set_engine("partykit") %>%
+#'   fit(Surv(time, status) ~ age + ph.ecog, data = lung)
+#' survival_prob_partykit(forest, lung[1:3, ], eval_time = 100)
 survival_prob_partykit <- function(object,
                                    new_data,
                                    eval_time,
                                    time = deprecated(),
                                    output = "surv") {
+  if (inherits(object, "party")) {
+    cli::cli_abort("{.arg object} needs to be a parsnip {.cls model_fit} object, not a {.cls party} object.")
+  }
+
   if (lifecycle::is_present(time)) {
     lifecycle::deprecate_warn(
       "0.2.0",
@@ -36,7 +47,7 @@ survival_prob_partykit <- function(object,
   # partykit handles missing values
   missings_in_new_data <- NULL
 
-  y <- predict(object, newdata = new_data, type = "prob")
+  y <- predict(object$fit, newdata = new_data, type = "prob")
 
   survfit_summary_list <- purrr::map(y, summary, times = eval_time, extend = TRUE)
   survfit_summary_combined <- combine_list_of_survfit_summary(
