@@ -1,6 +1,8 @@
 library(testthat)
 
 test_that("model object", {
+  skip_if_not_installed("flexsurv")
+  
   set.seed(1234)
   exp_f_fit <- flexsurv::flexsurvreg(
     Surv(time, status) ~ age + ph.ecog,
@@ -29,6 +31,8 @@ test_that("model object", {
 # prediction: time --------------------------------------------------------
 
 test_that("flexsurv time prediction", {
+  skip_if_not_installed("flexsurv")
+
   exp_fit <- flexsurv::flexsurvreg(
     Surv(time, status) ~ age,
     data = lung,
@@ -52,6 +56,8 @@ test_that("flexsurv time prediction", {
 # prediction: survival ----------------------------------------------------
 
 test_that("survival probability prediction", {
+  skip_if_not_installed("flexsurv")
+
   rms_surv <- readRDS(test_path("data", "rms_surv.rds"))
   f_fit <- survival_reg(dist = "weibull") %>%
     set_engine("flexsurv") %>%
@@ -121,6 +127,8 @@ test_that("survival probability prediction", {
 })
 
 test_that("survival probabilities for single eval time point", {
+  skip_if_not_installed("flexsurv")
+
   f_fit <- survival_reg(engine = "flexsurv") %>%
     fit(Surv(time, status) ~ age + sex, data = lung)
 
@@ -139,9 +147,31 @@ test_that("survival probabilities for single eval time point", {
   )
 })
 
+test_that("can predict for out-of-domain timepoints", {
+  skip_if_not_installed("flexsurv")
+  
+  eval_time_obs_max_and_ood <- c(1022, 2000)
+  obs_without_NA <- lung[2,]
+
+  mod <- survival_reg() %>%
+    set_mode("censored regression") %>%
+    set_engine("flexsurv") %>%
+    fit(Surv(time, status) ~ ., data = lung) %>%
+    suppressWarnings()
+
+  expect_no_error(
+    preds <- predict(mod, obs_without_NA, type = "survival", eval_time = eval_time_obs_max_and_ood)
+  )
+  expect_no_error(
+    preds <- predict(mod, obs_without_NA, type = "hazard", eval_time = eval_time_obs_max_and_ood)
+  )
+})
+
 # prediction: linear_pred -------------------------------------------------
 
 test_that("linear predictor", {
+  skip_if_not_installed("flexsurv")
+
   f_fit <- survival_reg() %>%
     set_engine("flexsurv") %>%
     fit(Surv(time, status) ~ age + sex, data = lung)
@@ -183,6 +213,8 @@ test_that("linear predictor", {
 # prediction: quantile ----------------------------------------------------
 
 test_that("quantile predictions", {
+  skip_if_not_installed("flexsurv")
+
   set.seed(1)
   fit_s <- survival_reg() %>%
     set_engine("flexsurv") %>%
@@ -248,6 +280,8 @@ test_that("quantile predictions", {
 # prediction: hazard ------------------------------------------------------
 
 test_that("hazard prediction", {
+  skip_if_not_installed("flexsurv")
+
   rms_haz <- readRDS(test_path("data", "rms_haz.rds"))
   f_fit <- survival_reg(dist = "weibull") %>%
     set_engine("flexsurv") %>%
@@ -296,6 +330,8 @@ test_that("hazard prediction", {
 })
 
 test_that("hazard for single eval time point", {
+  skip_if_not_installed("flexsurv")
+
   f_fit <- survival_reg(engine = "flexsurv") %>%
     fit(Surv(time, status) ~ age + sex, data = lung)
 
@@ -317,6 +353,8 @@ test_that("hazard for single eval time point", {
 # fit via matrix interface ------------------------------------------------
 
 test_that("`fix_xy()` works", {
+  skip_if_not_installed("flexsurv")
+  
   lung_x <- as.matrix(lung[, c("age", "ph.ecog")])
   lung_y <- Surv(lung$time, lung$status)
   lung_pred <- lung[1:5, ]
