@@ -75,6 +75,22 @@ test_that("survival probability prediction", {
   expect_identical(nrow(f_pred_1), 1L)
 })
 
+test_that("can predict for out-of-domain timepoints", {
+  eval_time_obs_max_and_ood <- c(1022, 2000)
+  obs_without_NA <- lung[2,]
+
+  mod <- survival_reg() %>%
+    set_mode("censored regression") %>%
+    set_engine("survival") %>%
+    fit(Surv(time, status) ~ ., data = lung)
+
+  expect_no_error(
+    preds <- predict(mod, obs_without_NA, type = "survival", eval_time = eval_time_obs_max_and_ood)
+  )
+  expect_no_error(
+    preds <- predict(mod, obs_without_NA, type = "hazard", eval_time = eval_time_obs_max_and_ood)
+  )
+})
 
 # prediction: linear_pred -------------------------------------------------
 
